## What's Changed

1. 修复：assistant message 中 tool_call 存在但 content 不存在时，导致验证错误的问题 ([#3862](https://github.com/AstrBotDevs/AstrBot/issues/3862))
2. 修复：fix: aiocqhttp 适配器 NapCat 文件名获取为空 ([#3853](https://github.com/AstrBotDevs/AstrBot/issues/3853))
3. 新增：升级所有插件按钮
4. 新增：/provider 指令支持同时测试提供商可用性
5. 优化：主动回复的 prompt